# Calendar utilities


### Getting started / Setup

You need to have at least python 2.7 and pip installed.
Run make from the project's root directory, all python dependencies required by the project will be installed.


## Running the tests

## Main dependencies

* [icalendar](https://icalendar.readthedocs.io/en/latest/about.html)  icalendar is a Python library to parse ICS files.

## Contributing

## Authors

* **Szilard Nemeth** - *Initial work* - [Szilard Nemeth](https://github.com/szilard-nemeth)

## License

## Acknowledgments

## Example commands

```calendarstats.py -f /Users/szilardnemeth/Downloads/snemeth@cloudera.com.ics --event-exceptions "Lunch" "REM: Rainbow Sheet!" "Busy [Usual shifted day]" "CDP-Data Center 7.1 Checkpoint Meeting" "Board game afternoon in Budapest" --filter-year 2019 2020```
